﻿using Syncfusion.SfDiagram.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace TreeLayout
{
    // Learn more about making custom code visible in the Xamarin.Forms previewer
    // by visiting https://aka.ms/xamarinforms-previewer
    [DesignTimeVisible(false)]
    public partial class MainPage : ContentPage
    {
        public MainPage()
        {
            InitializeComponent();
            //Employees data source
            var employees = new ObservableCollection<Employee>();
            employees.Add(new Employee() { name = "Elizabeth", id = 1, parentId = 0, designation = "CEO" });
            employees.Add(new Employee() { name = "Christina", id = 2, parentId = 1, designation = "Manager" });
            employees.Add(new Employee() { name = "Yang", id = 3, parentId = 1, designation = "Manager" });

            //Diagram layouting
            diagram.DataSourceSettings = new DataSourceSettings() { DataSource = employees, Id = "id", ParentId = "parentId" };

            DirectedTreeLayout treeLayout = new DirectedTreeLayout()
            {
                HorizontalSpacing = 80,
                VerticalSpacing = 80,
                TreeOrientation = TreeOrientation.TopToBottom
            };

            diagram.LayoutManager = new LayoutManager()
            {
                Layout = treeLayout
            };

            diagram.BeginNodeRender += Diagram_BeginNodeRender;
        }

        //Customizing node while rendering layout 
        private void Diagram_BeginNodeRender(object sender, BeginNodeRenderEventArgs args)
        {
            Node node = args.Item;
            node.Width = 80;
            node.Height = 80;
            Grid parent;
            var template = new DataTemplate(() =>
            {
                parent = new Grid();
                parent.WidthRequest = parent.HeightRequest = 80;
                Label label = new Label
                {
                    BackgroundColor = Color.Red,
                    TextColor = Color.Green,
                    Text = (node.Content as Employee).name
                };
                parent.Children.Add(label);
                return parent;
            });

            node.Template = template;
        }
    }

    public class Employee
    {
        public string name { get; set; }
        public int parentId { get; set; }
        public int id { get; set; }
        public string designation { get; set; }
        public Employee()
        {

        }
    }
}
